/*
 * 다음과 같은 과정으로 채점된다고 가정해도 좋습니다.
 *
 * Pass 1:  ./workshop < %03d.in.txt > output1.txt
 * Pass 2:  ./workshop < output1.txt > output2.txt
 * Checker: ./checker %03d.in.txt output2.txt answer.txt
 */

#include "workshop.h"
#include <vector>
#include <string>
#include <cassert>
#include <random>
#include <cstdio>
#include <map>
#include <algorithm>
#include <array>
#include <utility>

using std::vector;
using std::mt19937;
using std::max;
using std::array;
#define sz(a) ((int)(a).size())
#define all(a) (a).begin(), (a).end()

namespace {
  static const std::string input_secret = "2dc2b1d4-8de2-INPUT-bcd3-aa55b691fdb3";
  static const std::string pipe_secret = "dd180566-1d37-PIPE-b85d-c176ae85727d";
  static const std::string output_secret = "4468cc07-dabe-OUTPUT-ba95-7ddd49645c94";
  static const std::string error_secret = "64be09ab-d709-ERROR-82bc-c23f6124dd26";
  
  static const int COMMON_XOR_HASH = 137;

  static FILE *infile = stdin;
  static FILE *outfile = stdout;

  enum QueryType {
    Morning,
    Afternoon,
    Evening,
  };

  struct FunctionCall {
    QueryType type;
    int a, b, c, v;
  };

  void my_error(std::string msg) {
    fprintf(outfile, "%s\n", error_secret.c_str());
    fprintf(outfile, "%s\n", msg.c_str());
    fclose(outfile);
    exit(0);
  }

  inline int readint() {
    int x;
    if (1 != fscanf(infile, "%d", &x)) my_error("SV");
    return x;
  }
  inline int readhexint() {
    int x;
    if (1 != fscanf(infile, "%x", &x)) my_error("SV");
    return x;
  }

  inline int my_morning(int a, int b) {
    int x = morning(a, b);
    if (!(x >= 0 && x < int(1e9))) my_error("Wrong Answer [1]");
    return x;
  }

  inline int my_afternoon(int a, int b, int c) {
    int x = afternoon(a, b, c);
    if (!(x >= 0 && x < int(1e9))) my_error("Wrong Answer [2]");
    return x;
  }

  inline int my_evening(int a, int b, int c) {
    int x = evening(a, b, c);
    if (!(x >= 0 && x < 40)) my_error("Wrong Answer [3]");
    return x;
  }

  void pass1() {
    int tc = readint();
    if (tc < 0) {
      my_error("SV22");
    }

    int q = readint();
    vector<vector<int>> v(q);
    vector<int> len(q);
    for (int i = 0; i < q; i++) {
      int n, m;
      n = readint();
      m = readint();
      v[i].resize(m);
      len[i] = n;
      for (auto &j : v[i]) j = readint();
    }

    init();

    auto initial = v;

    mt19937 rng(0x14004);
    // idk, just shuffle each steps
    vector<vector<int>> morning_result;
    {
      vector<array<int, 4>> events;
      for (int i = 0; i < q; i++) {
        for (int j = 0; j < sz(v[i]); j++) {
          if (j + 1 == sz(v[i]) && sz(v[i]) < len[i])
            break;
          events.push_back({v[i][j], v[i][(j + 1) % sz(v[i])], i, j});
        }
        if (sz(v[i]) < len[i])
          v[i].pop_back();
      }
      shuffle(all(events), rng);
      for (auto &x : events) {
        int res = my_morning(x[0], x[1]);
        v[x[2]][x[3]] = res;
      }
      morning_result = v;
    }

    vector<vector<int>> afternoon_result;
    {
      vector<array<int, 5>> events;
      for (int i = 0; i < q; i++) {
        for (int j = 0; j < sz(v[i]); j++) {
          if (j + 2 == sz(v[i]) && sz(v[i]) < len[i])
            break;
          events.push_back({v[i][j], v[i][(j + 1) % sz(v[i])], v[i][(j + 2) % sz(v[i])], i, j});
        }
        if (sz(v[i]) < len[i]) {
          v[i].pop_back();
          v[i].pop_back();
        }
      }
      shuffle(all(events), rng);
      for (auto &x : events) {
        int res = my_afternoon(x[0], x[1], x[2]);
        v[x[3]][x[4]] = res;
      }
      afternoon_result = v;
    }

    {
      vector<array<int, 5>> events;
      for (int i = 0; i < q; i++) {
        for (int j = 0; j < sz(v[i]); j++) {
          if (j + 2 == sz(v[i]) && sz(v[i]) < len[i])
            break;
          events.push_back({v[i][j], v[i][(j + 1) % sz(v[i])], v[i][(j + 2) % sz(v[i])], i, j});
        }
        if (sz(v[i]) < len[i]) {
          v[i].pop_back();
          v[i].pop_back();
        }
      }
      shuffle(all(events), rng);
      for (auto &x : events) {
        int res = my_evening(x[0], x[1], x[2]);
        v[x[3]][x[4]] = res;
      }
    }

    int ans = 0;
    for (int i = 0; i < q; i++) {
      for (int j = 0; j < sz(v[i]); j++) {
        ans = max(ans, v[i][j] + 1);
      }
      for (int j = 0; j < sz(v[i]); j++) {
        if (j + 1 == sz(v[i]) && sz(v[i]) < len[i])
          break;
        if (v[i][j] == v[i][(j + 1) % sz(v[i])]) {
          my_error("Wrong Answer [4]");
        }
      }
    }


    fprintf(outfile, "%s\n", pipe_secret.c_str());
    fprintf(outfile, "%d %d\n", ans, q);
    for (int i = 0; i < q; i++) {
      fprintf(outfile, "%x %x %x %x\n", sz(initial[i]), sz(morning_result[i]), sz(afternoon_result[i]), sz(v[i]));
      for (auto &x : initial[i]) fprintf(outfile, "%x ", x ^ COMMON_XOR_HASH);
      fprintf(outfile, "\n");
      for (auto &x : morning_result[i]) fprintf(outfile, "%08x ", x ^ COMMON_XOR_HASH);
      fprintf(outfile, "\n");
      for (auto &x : afternoon_result[i]) fprintf(outfile, "%08x ", x ^ COMMON_XOR_HASH);
      fprintf(outfile, "\n");
      for (auto &x : v[i]) fprintf(outfile, "%02x ", x ^ COMMON_XOR_HASH);
      fprintf(outfile, "\n");
    }
  }

  void pass2() {
    mt19937 rng(0x31415926535);

    int ans = readint();
    int q = readint();

    init();

    std::vector<FunctionCall> calls;
    for (int i = 0; i < q; i++) {
      int sz_initial, sz_morning, sz_afternoon, sz_evening;
      sz_initial = readhexint();
      sz_morning = readhexint();
      sz_afternoon = readhexint();
      sz_evening = readhexint();

      std::vector<int> initial(sz_initial);
      for (int j = 0; j < sz_initial; j++) {
        initial[j] = readhexint() ^ COMMON_XOR_HASH;
      }

      std::vector<int> morning(sz_morning);
      for (int j = 0; j < sz_morning; j++) {
        morning[j] = readhexint() ^ COMMON_XOR_HASH;
      }

      std::vector<int> afternoon(sz_afternoon);
      for (int j = 0; j < sz_afternoon; j++) {
        afternoon[j] = readhexint() ^ COMMON_XOR_HASH;
      }

      std::vector<int> evening(sz_evening);
      for (int j = 0; j < sz_evening; j++) {
        evening[j] = readhexint() ^ COMMON_XOR_HASH;
      }

      for (int j = 0; j < sz_morning; j++) {
        calls.push_back({ Morning, initial[j], initial[(j + 1) % sz_initial], -1, morning[j] });
      }
      for (int j = 0; j < sz_afternoon; j++) {
        calls.push_back({ Afternoon, morning[j], morning[(j + 1) % sz_morning], morning[(j + 2) % sz_morning], afternoon[j] });
      }
      for (int j = 0; j < sz_evening; j++) {
        calls.push_back({ Evening, afternoon[j], afternoon[(j + 1) % sz_afternoon], afternoon[(j + 2) % sz_afternoon], evening[j] });
      }
    }

    shuffle(all(calls), rng);

    for (auto &call : calls) {
      if (call.type == Morning) {
        int res = my_morning(call.a, call.b);
        if (res != call.v) {
          my_error("Wrong Answer [5]");
        }
      }
      else if (call.type == Afternoon) {
        int res = my_afternoon(call.a, call.b, call.c);
        if (res != call.v) {
          my_error("Wrong Answer [6]");
        }
      }
      else if (call.type == Evening) {
        int res = my_evening(call.a, call.b, call.c);
        if (res != call.v) {
          my_error("Wrong Answer [7]");
        }
      }
    }

    printf("%s\n", output_secret.c_str());
    printf("%d\n", ans);
  }
}

int main() {
  char secret[1000];
  if(1 != scanf("%995s\n", secret)) my_error("SV33");
  if(std::string(secret) == input_secret) pass1();
  else if(std::string(secret) == pipe_secret) pass2();
  else if(std::string(secret) == error_secret) {
    fprintf(outfile, "%s\n", error_secret.c_str());
    char buf[1000];
    while (fgets(buf, 1000, infile)) {
      fprintf(outfile, "%s", buf);
    }
  }
  else my_error("SV44");
  return 0;
}
